from yamcs.core.helpers import parse_isostring
from yamcs.protobuf import yamcs_pb2
from yamcs.protobuf.yamcsManagement import yamcsManagement_pb2


class AuthInfo(object):
    """
    Authentication information
    """

    def __init__(self, proto):
        self._proto = proto

    @property
    def require_authentication(self):
        return self._proto.requireAuthentication


class ServerInfo(object):
    """
    General server properties.
    """

    def __init__(self, proto):
        self._proto = proto

    @property
    def id(self):
        """The Server ID."""
        return self._proto.serverId

    @property
    def version(self):
        """The version of Yamcs Server."""
        return self._proto.yamcsVersion

    @property
    def default_yamcs_instance(self):
        """Returns the default Yamcs instance."""
        if self._proto.HasField('defaultYamcsInstance'):
            return self._proto.defaultYamcsInstance
        return None

    def __str__(self):
        return '{} (v{})'.format(self.id, self.version)


class UserInfo(object):
    """
    Info on a Yamcs User.
    """

    def __init__(self, proto):
        self._proto = proto

    @property
    def username(self):
        return self._proto.login

    @property
    def superuser(self):
        return self._proto.superuser

    @property
    def system_privileges(self):
        return [p for p in self._proto.systemPrivilege]

    @property
    def object_privileges(self):
        return [ObjectPrivilege(p) for p in self._proto.objectPrivilege]

    @property
    def clients(self):
        return [Client(c) for c in self._proto.clientInfo]

    def __str__(self):
        return self.username


class ObjectPrivilege(object):

    def __init__(self, proto):
        self._proto = proto

    @property
    def name(self):
        return self._proto.type

    @property
    def objects(self):
        return [o for o in self._proto.object]

    def __str__(self):
        return self.name


class Event(object):
    """
    A timetagged free-text message. Events work a lot like log
    messages in logging frameworks, but then targeted at operators.
    """

    def __init__(self, proto):
        self._proto = proto

    @property
    def generation_time(self):
        """
        The time when the event was generated.

        :type: :class:`~datetime.datetime`
        """
        if self._proto.HasField('generationTimeUTC'):
            return parse_isostring(self._proto.generationTimeUTC)
        return None

    @property
    def reception_time(self):
        """
        The time when the event was received by Yamcs.

        :type: :class:`~datetime.datetime`
        """
        if self._proto.HasField('receptionTimeUTC'):
            return parse_isostring(self._proto.receptionTimeUTC)
        return None

    @property
    def severity(self):
        """
        Severity level of the event. One of ``INFO``, ``WATCH``,
        ``WARNING``, ``DISTRESS``, ``CRITICAL`` or ``SEVERE``.
        """
        if self._proto.HasField('severity'):
            return yamcs_pb2.Event.EventSeverity.Name(self._proto.severity)
        return None

    @property
    def message(self):
        """
        Event message.
        """
        if self._proto.HasField('message'):
            return self._proto.message
        return None

    @property
    def sequence_number(self):
        """
        Sequence number. Usually this is assigned by the source of the event.
        """
        if self._proto.HasField('seqNumber'):
            return self._proto.seqNumber
        return None

    @property
    def event_type(self):
        """
        The event type. This is mission-specific and can be any string.
        """
        if self._proto.HasField('type'):
            return self._proto.type
        return None

    @property
    def source(self):
        """
        The event source. Can be any string.
        """
        if self._proto.HasField('source'):
            return self._proto.source
        return None

    def __str__(self):
        return '{} [{}] {}'.format(self.generation_time, self.severity, self.message)


class LinkEvent(object):
    """
    Data holder used in link subscriptions.
    """

    def __init__(self, proto):
        self._proto = proto

    @property
    def event_type(self):
        """
        The type of the event. One of ``REGISTERED``, ``UNREGISTERED``,
        or ``UPDATED``.
        """
        return yamcsManagement_pb2.LinkEvent.Type.Name(self._proto.type)

    @property
    def link(self):
        """
        Link state at the time of this event.

        :type: :class:`.Link`
        """
        return Link(self._proto.linkInfo)

    def __str__(self):
        return '[{}] {}'.format(self.event_type, self.link)

class Link(object):
    """
    Represents a link with an external system. Depending on the
    semantics of the link, this may imply inbound data, outbound
    data or a combination of both.
    """

    def __init__(self, proto):
        self._proto = proto

    @property
    def instance(self):
        """Name of the instance where this link is defined."""
        return self._proto.instance

    @property
    def name(self):
        """Name of this link (unique per instance)."""
        return self._proto.name

    @property
    def class_name(self):
        """Name of this link's class."""
        return self._proto.type

    @property
    def enabled(self):
        """If ``True``, this link accepts or outputs data."""
        return not self._proto.disabled

    @property
    def status(self):
        """Short status."""
        return self._proto.status

    @property
    def in_count(self):
        """The number of inbound data events (example: packet count)."""
        return self._proto.dataInCount

    @property
    def out_count(self):
        """The number of outbound data events (example: command count)."""
        return self._proto.dataOutCount

    def __str__(self):
        return '{}/{}: {} (in: {} out: {})'.format(
            self.instance, self.name, self.status, self.in_count, self.out_count)


class Instance(object):

    def __init__(self, proto):
        self._proto = proto

    @property
    def name(self):
        """Name of this instance."""
        return self._proto.name

    @property
    def state(self):
        """
        State of this instance. One of ``OFFLINE``, ``INITIALIZING``,
        ``INITIALIZED``, ``STARTING``, ``RUNNING``, ``STOPPING`` or
        ``FAILED``.
        """
        if self._proto.HasField('state'):
            return yamcsManagement_pb2.YamcsInstance.InstanceState.Name(self._proto.state)
        return None

    @property
    def failure_cause(self):
        """Failure message when ``state == 'FAILED'``"""
        if self._proto.HasField('failureCause'):
            return self._proto.failureCause
        return None

    @property
    def mission_time(self):
        """
        Mission time of this instance's time service.

        :type: :class:`~datetime.datetime`
        """
        if self._proto.HasField('missionTime'):
            return parse_isostring(self._proto.missionTime)
        return None

    def __str__(self):
        return '{} [{}]'.format(self.name, self.state)


class InstanceTemplate(object):
    """A template for creating an instance."""

    def __init__(self, proto):
        self._proto = proto

    @property
    def name(self):
        """Name of this template."""
        return self._proto.name

    def __str__(self):
        return self.name


class Service(object):
    """A Yamcs service."""

    def __init__(self, proto):
        self._proto = proto

    @property
    def name(self):
        """Name of this service."""
        return self._proto.name

    @property
    def instance(self):
        """Name of the instance where this service is defined."""
        if self._proto.HasField('instance'):
            return self._proto.instance
        return None

    @property
    def processor(self):
        """Name of the processor where this service is defined."""
        if self._proto.HasField('processor'):
            return self._proto.processor
        return None

    @property
    def class_name(self):
        """Name of this service's class."""
        return self._proto.className

    @property
    def state(self):
        """State of this service."""
        if self._proto.HasField('state'):
            return yamcsManagement_pb2.ServiceState.Name(self._proto.state)
        return None

    def __str__(self):
        return '{} [{}]'.format(self.name, self.state)


class Client(object):
    """A user session."""

    def __init__(self, proto):
        self._proto = proto

    @property
    def id(self):
        """Session ID."""
        return self._proto.id

    @property
    def username(self):
        """Username associated with this session."""
        return self._proto.username

    @property
    def application_name(self):
        """Application name (user agent)."""
        if self._proto.HasField('applicationName'):
            return self._proto.applicationName
        return None

    @property
    def login_time(self):
        """
        Time when this session started.

        :type: :class:`~datetime.datetime`
        """
        if self._proto.HasField('loginTimeUTC'):
            return parse_isostring(self._proto.loginTimeUTC)
        return None

    def __str__(self):
        return self.username


class Processor(object):

    def __init__(self, proto):
        self._proto = proto

    @property
    def name(self):
        """Name of this processor."""
        return self._proto.name

    @property
    def instance(self):
        """Name of the instance where this processor is defined."""
        return self._proto.instance

    @property
    def state(self):
        """State of this processor."""
        if self._proto.HasField('state'):
            return yamcsManagement_pb2.ServiceState.Name(self._proto.state)
        return None

    @property
    def type(self):
        """Type of this processor."""
        return self._proto.type

    @property
    def owner(self):
        """User that owns this processor."""
        return self._proto.creator

    @property
    def persistent(self):
        """If ``True``, this processor does not close if no clients are connected."""
        return not self._proto.persistent

    @property
    def mission_time(self):
        """
        Mission time of this processor.

        :type: :class:`~datetime.datetime`
        """
        if self._proto.HasField('time'):
            return parse_isostring(self._proto.time)
        return None

    def __str__(self):
        return '{} [{}]'.format(self.name, self.state)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/archive/export_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2
from yamcs.api import httpbody_pb2 as yamcs_dot_api_dot_httpbody__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/archive/export_service.proto',
  package='yamcs.protobuf.archive',
  syntax='proto2',
  serialized_options=_b('\n\022org.yamcs.protobufB\022ExportServiceProtoP\001'),
  serialized_pb=_b('\n+yamcs/protobuf/archive/export_service.proto\x12\x16yamcs.protobuf.archive\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1byamcs/api/annotations.proto\x1a\x18yamcs/api/httpbody.proto\"\x8b\x01\n\x14\x45xportPacketsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12)\n\x05start\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x03(\t\"\xa9\x01\n\x13\x45xportEventsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12)\n\x05start\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06source\x18\x04 \x03(\t\x12\x10\n\x08severity\x18\x05 \x01(\t\x12\t\n\x01q\x18\x06 \x01(\t\"\xbb\x01\n\x1c\x45xportParameterValuesRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12)\n\x05start\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nparameters\x18\x04 \x03(\t\x12\x11\n\tnamespace\x18\x05 \x01(\t\x12\r\n\x05\x65xtra\x18\x06 \x03(\t2\xab\x03\n\tExportApi\x12\x81\x01\n\rExportPackets\x12,.yamcs.protobuf.archive.ExportPacketsRequest\x1a\x13.yamcs.api.HttpBody\"+\x8a\x92\x03\'\n%/api/archive/{instance}:exportPackets0\x01\x12~\n\x0c\x45xportEvents\x12+.yamcs.protobuf.archive.ExportEventsRequest\x1a\x13.yamcs.api.HttpBody\"*\x8a\x92\x03&\n$/api/archive/{instance}:exportEvents0\x01\x12\x99\x01\n\x15\x45xportParameterValues\x12\x34.yamcs.protobuf.archive.ExportParameterValuesRequest\x1a\x13.yamcs.api.HttpBody\"3\x8a\x92\x03/\n-/api/archive/{instance}:exportParameterValues0\x01\x42*\n\x12org.yamcs.protobufB\x12\x45xportServiceProtoP\x01')
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,yamcs_dot_api_dot_httpbody__pb2.DESCRIPTOR,])




_EXPORTPACKETSREQUEST = _descriptor.Descriptor(
  name='ExportPacketsRequest',
  full_name='yamcs.protobuf.archive.ExportPacketsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.ExportPacketsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.archive.ExportPacketsRequest.start', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.archive.ExportPacketsRequest.stop', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.archive.ExportPacketsRequest.name', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=160,
  serialized_end=299,
)


_EXPORTEVENTSREQUEST = _descriptor.Descriptor(
  name='ExportEventsRequest',
  full_name='yamcs.protobuf.archive.ExportEventsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.ExportEventsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.archive.ExportEventsRequest.start', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.archive.ExportEventsRequest.stop', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source', full_name='yamcs.protobuf.archive.ExportEventsRequest.source', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='severity', full_name='yamcs.protobuf.archive.ExportEventsRequest.severity', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='q', full_name='yamcs.protobuf.archive.ExportEventsRequest.q', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=302,
  serialized_end=471,
)


_EXPORTPARAMETERVALUESREQUEST = _descriptor.Descriptor(
  name='ExportParameterValuesRequest',
  full_name='yamcs.protobuf.archive.ExportParameterValuesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.ExportParameterValuesRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.archive.ExportParameterValuesRequest.start', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.archive.ExportParameterValuesRequest.stop', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parameters', full_name='yamcs.protobuf.archive.ExportParameterValuesRequest.parameters', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='yamcs.protobuf.archive.ExportParameterValuesRequest.namespace', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extra', full_name='yamcs.protobuf.archive.ExportParameterValuesRequest.extra', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=474,
  serialized_end=661,
)

_EXPORTPACKETSREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EXPORTPACKETSREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EXPORTEVENTSREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EXPORTEVENTSREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EXPORTPARAMETERVALUESREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EXPORTPARAMETERVALUESREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['ExportPacketsRequest'] = _EXPORTPACKETSREQUEST
DESCRIPTOR.message_types_by_name['ExportEventsRequest'] = _EXPORTEVENTSREQUEST
DESCRIPTOR.message_types_by_name['ExportParameterValuesRequest'] = _EXPORTPARAMETERVALUESREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ExportPacketsRequest = _reflection.GeneratedProtocolMessageType('ExportPacketsRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXPORTPACKETSREQUEST,
  '__module__' : 'yamcs.protobuf.archive.export_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.ExportPacketsRequest)
  })
_sym_db.RegisterMessage(ExportPacketsRequest)

ExportEventsRequest = _reflection.GeneratedProtocolMessageType('ExportEventsRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXPORTEVENTSREQUEST,
  '__module__' : 'yamcs.protobuf.archive.export_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.ExportEventsRequest)
  })
_sym_db.RegisterMessage(ExportEventsRequest)

ExportParameterValuesRequest = _reflection.GeneratedProtocolMessageType('ExportParameterValuesRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXPORTPARAMETERVALUESREQUEST,
  '__module__' : 'yamcs.protobuf.archive.export_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.ExportParameterValuesRequest)
  })
_sym_db.RegisterMessage(ExportParameterValuesRequest)


DESCRIPTOR._options = None

_EXPORTAPI = _descriptor.ServiceDescriptor(
  name='ExportApi',
  full_name='yamcs.protobuf.archive.ExportApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=664,
  serialized_end=1091,
  methods=[
  _descriptor.MethodDescriptor(
    name='ExportPackets',
    full_name='yamcs.protobuf.archive.ExportApi.ExportPackets',
    index=0,
    containing_service=None,
    input_type=_EXPORTPACKETSREQUEST,
    output_type=yamcs_dot_api_dot_httpbody__pb2._HTTPBODY,
    serialized_options=_b('\212\222\003\'\n%/api/archive/{instance}:exportPackets'),
  ),
  _descriptor.MethodDescriptor(
    name='ExportEvents',
    full_name='yamcs.protobuf.archive.ExportApi.ExportEvents',
    index=1,
    containing_service=None,
    input_type=_EXPORTEVENTSREQUEST,
    output_type=yamcs_dot_api_dot_httpbody__pb2._HTTPBODY,
    serialized_options=_b('\212\222\003&\n$/api/archive/{instance}:exportEvents'),
  ),
  _descriptor.MethodDescriptor(
    name='ExportParameterValues',
    full_name='yamcs.protobuf.archive.ExportApi.ExportParameterValues',
    index=2,
    containing_service=None,
    input_type=_EXPORTPARAMETERVALUESREQUEST,
    output_type=yamcs_dot_api_dot_httpbody__pb2._HTTPBODY,
    serialized_options=_b('\212\222\003/\n-/api/archive/{instance}:exportParameterValues'),
  ),
])
_sym_db.RegisterServiceDescriptor(_EXPORTAPI)

DESCRIPTOR.services_by_name['ExportApi'] = _EXPORTAPI

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/web/websocket.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yamcs.protobuf import yamcs_pb2 as yamcs_dot_protobuf_dot_yamcs__pb2
from yamcs.protobuf.table import table_pb2 as yamcs_dot_protobuf_dot_table_dot_table__pb2
from yamcs.protobuf.commanding import commanding_pb2 as yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2
from yamcs.protobuf.pvalue import pvalue_pb2 as yamcs_dot_protobuf_dot_pvalue_dot_pvalue__pb2
from yamcs.protobuf.alarms import alarms_pb2 as yamcs_dot_protobuf_dot_alarms_dot_alarms__pb2
from yamcs.protobuf.iam import iam_pb2 as yamcs_dot_protobuf_dot_iam_dot_iam__pb2
from yamcs.protobuf.yamcsManagement import yamcsManagement_pb2 as yamcs_dot_protobuf_dot_yamcsManagement_dot_yamcsManagement__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/web/websocket.proto',
  package='yamcs.protobuf.web',
  syntax='proto2',
  serialized_options=_b('\n\022org.yamcs.protobufB\016WebSocketProtoP\001'),
  serialized_pb=_b('\n\"yamcs/protobuf/web/websocket.proto\x12\x12yamcs.protobuf.web\x1a\x1ayamcs/protobuf/yamcs.proto\x1a yamcs/protobuf/table/table.proto\x1a*yamcs/protobuf/commanding/commanding.proto\x1a\"yamcs/protobuf/pvalue/pvalue.proto\x1a\"yamcs/protobuf/alarms/alarms.proto\x1a\x1cyamcs/protobuf/iam/iam.proto\x1a\x34yamcs/protobuf/yamcsManagement/yamcsManagement.proto\"|\n\x16WebSocketClientMessage\x12\x17\n\x0fprotocolVersion\x18\x01 \x01(\r\x12\x16\n\x0esequenceNumber\x18\x02 \x01(\r\x12\x10\n\x08resource\x18\x03 \x01(\t\x12\x11\n\toperation\x18\x04 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x05 \x01(\x0c\"\x98\r\n\x16WebSocketServerMessage\x12\x44\n\x04type\x18\x01 \x01(\x0e\x32\x36.yamcs.protobuf.web.WebSocketServerMessage.MessageType\x12L\n\x05reply\x18\x02 \x01(\x0b\x32=.yamcs.protobuf.web.WebSocketServerMessage.WebSocketReplyData\x12T\n\texception\x18\x03 \x01(\x0b\x32\x41.yamcs.protobuf.web.WebSocketServerMessage.WebSocketExceptionData\x12R\n\x04\x64\x61ta\x18\x04 \x01(\x0b\x32\x44.yamcs.protobuf.web.WebSocketServerMessage.WebSocketSubscriptionData\x1ar\n\x12WebSocketReplyData\x12\x17\n\x0fprotocolVersion\x18\x01 \x01(\r\x12\x16\n\x0esequenceNumber\x18\x02 \x01(\x05\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x0f\n\x07message\x18\x04 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x05 \x01(\x0c\x1av\n\x16WebSocketExceptionData\x12\x17\n\x0fprotocolVersion\x18\x01 \x01(\r\x12\x16\n\x0esequenceNumber\x18\x02 \x01(\x05\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x0f\n\x07message\x18\x04 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x05 \x01(\x0c\x1a\xa0\x08\n\x19WebSocketSubscriptionData\x12\x16\n\x0esequenceNumber\x18\x01 \x01(\r\x12+\n\x04type\x18\x02 \x01(\x0e\x32\x1d.yamcs.protobuf.ProtoDataType\x12;\n\rparameterData\x18\x03 \x01(\x0b\x32$.yamcs.protobuf.pvalue.ParameterData\x12?\n\x07\x63ommand\x18\x04 \x01(\x0b\x32..yamcs.protobuf.commanding.CommandHistoryEntry\x12\x44\n\rprocessorInfo\x18\x05 \x01(\x0b\x32-.yamcs.protobuf.yamcsManagement.ProcessorInfo\x12>\n\nclientInfo\x18\x06 \x01(\x0b\x32*.yamcs.protobuf.yamcsManagement.ClientInfo\x12>\n\nstatistics\x18\x07 \x01(\x0b\x32*.yamcs.protobuf.yamcsManagement.Statistics\x12$\n\x05\x65vent\x18\x08 \x01(\x0b\x32\x15.yamcs.protobuf.Event\x12\x34\n\nstreamData\x18\t \x01(\x0b\x32 .yamcs.protobuf.table.StreamData\x12\x33\n\talarmData\x18\n \x01(\x0b\x32 .yamcs.protobuf.alarms.AlarmData\x12*\n\x08timeInfo\x18\x0b \x01(\x0b\x32\x18.yamcs.protobuf.TimeInfo\x12<\n\tlinkEvent\x18\x0c \x01(\x0b\x32).yamcs.protobuf.yamcsManagement.LinkEvent\x12\x45\n\x10\x63ommandQueueInfo\x18\r \x01(\x0b\x32+.yamcs.protobuf.commanding.CommandQueueInfo\x12G\n\x11\x63ommandQueueEvent\x18\x0e \x01(\x0b\x32,.yamcs.protobuf.commanding.CommandQueueEvent\x12.\n\x08tmPacket\x18\x0f \x01(\x0b\x32\x1c.yamcs.protobuf.TmPacketData\x12:\n\x0e\x63onnectionInfo\x18\x10 \x01(\x0b\x32\".yamcs.protobuf.web.ConnectionInfo\x12@\n\x0bstreamEvent\x18\x11 \x01(\x0b\x32+.yamcs.protobuf.yamcsManagement.StreamEvent\x12\x41\n\rextensionData\x18\x64 \x01(\x0b\x32*.yamcs.protobuf.web.WebSocketExtensionData\"1\n\x0bMessageType\x12\t\n\x05REPLY\x10\x02\x12\r\n\tEXCEPTION\x10\x03\x12\x08\n\x04\x44\x41TA\x10\x04\"4\n\x16WebSocketExtensionData\x12\x0c\n\x04type\x18\x01 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"+\n\x17LinkSubscriptionRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\".\n\x1aStreamsSubscriptionRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\"+\n\x17\x43\x66\x64pSubscriptionRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\"K\n\x1cProcessorSubscriptionRequest\x12\x15\n\rallProcessors\x18\x01 \x01(\x08\x12\x14\n\x0c\x61llInstances\x18\x02 \x01(\x08\"P\n\x1dManagementSubscriptionRequest\x12\x12\n\nclientInfo\x18\x01 \x01(\x08\x12\x1b\n\x13processorStatistics\x18\x03 \x01(\x08\"*\n\x18\x41larmSubscriptionRequest\x12\x0e\n\x06\x64\x65tail\x18\x01 \x01(\x08\"|\n!CommandHistorySubscriptionRequest\x12;\n\tcommandId\x18\x01 \x03(\x0b\x32$.yamcs.protobuf.commanding.CommandIdB\x02\x18\x01\x12\x1a\n\x12ignorePastCommands\x18\x02 \x01(\x08\"\xc3\x01\n\x1cParameterSubscriptionRequest\x12)\n\x02id\x18\x01 \x03(\x0b\x32\x1d.yamcs.protobuf.NamedObjectId\x12\x16\n\x0e\x61\x62ortOnInvalid\x18\x02 \x01(\x08\x12\x1a\n\x12updateOnExpiration\x18\x03 \x01(\x08\x12\x15\n\rsendFromCache\x18\x04 \x01(\x08\x12\x16\n\x0esubscriptionId\x18\x05 \x01(\x05\x12\x15\n\ruseNumericIds\x18\x06 \x01(\x08\"S\n\x13SubscribedParameter\x12)\n\x02id\x18\x01 \x01(\x0b\x32\x1d.yamcs.protobuf.NamedObjectId\x12\x11\n\tnumericId\x18\x02 \x01(\r\"\xa4\x01\n\x1dParameterSubscriptionResponse\x12.\n\x07invalid\x18\x02 \x03(\x0b\x32\x1d.yamcs.protobuf.NamedObjectId\x12\x16\n\x0esubscriptionId\x18\x03 \x01(\x05\x12;\n\nsubscribed\x18\x04 \x03(\x0b\x32\'.yamcs.protobuf.web.SubscribedParameter\"F\n\x18TimeSubscriptionResponse\x12*\n\x08timeInfo\x18\x01 \x01(\x0b\x32\x18.yamcs.protobuf.TimeInfo\"a\n\x1dProcessorSubscriptionResponse\x12@\n\tprocessor\x18\x01 \x01(\x0b\x32-.yamcs.protobuf.yamcsManagement.ProcessorInfo\"\xa5\x01\n\x0e\x43onnectionInfo\x12\x10\n\x08\x63lientId\x18\x01 \x01(\x05\x12?\n\x08instance\x18\x02 \x01(\x0b\x32-.yamcs.protobuf.yamcsManagement.YamcsInstance\x12@\n\tprocessor\x18\x03 \x01(\x0b\x32-.yamcs.protobuf.yamcsManagement.ProcessorInfo\"k\n\x08\x41uthFlow\x12/\n\x04type\x18\x01 \x01(\x0e\x32!.yamcs.protobuf.web.AuthFlow.Type\".\n\x04Type\x12\x0c\n\x08PASSWORD\x10\x01\x12\x0c\n\x08REDIRECT\x10\x02\x12\n\n\x06SPNEGO\x10\x03\"U\n\x08\x41uthInfo\x12\x1d\n\x15requireAuthentication\x18\x01 \x01(\x08\x12*\n\x04\x66low\x18\x02 \x03(\x0b\x32\x1c.yamcs.protobuf.web.AuthFlow\"\x90\x01\n\rTokenResponse\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x12\n\ntoken_type\x18\x02 \x01(\t\x12\x12\n\nexpires_in\x18\x03 \x01(\x05\x12\x15\n\rrefresh_token\x18\x04 \x01(\t\x12*\n\x04user\x18\x05 \x01(\x0b\x32\x1c.yamcs.protobuf.iam.UserInfoB&\n\x12org.yamcs.protobufB\x0eWebSocketProtoP\x01')
  ,
  dependencies=[yamcs_dot_protobuf_dot_yamcs__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_table_dot_table__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_pvalue_dot_pvalue__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_alarms_dot_alarms__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_iam_dot_iam__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_yamcsManagement_dot_yamcsManagement__pb2.DESCRIPTOR,])



_WEBSOCKETSERVERMESSAGE_MESSAGETYPE = _descriptor.EnumDescriptor(
  name='MessageType',
  full_name='yamcs.protobuf.web.WebSocketServerMessage.MessageType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='REPLY', index=0, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXCEPTION', index=1, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DATA', index=2, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2086,
  serialized_end=2135,
)
_sym_db.RegisterEnumDescriptor(_WEBSOCKETSERVERMESSAGE_MESSAGETYPE)

_AUTHFLOW_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='yamcs.protobuf.web.AuthFlow.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PASSWORD', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REDIRECT', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SPNEGO', index=2, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3508,
  serialized_end=3554,
)
_sym_db.RegisterEnumDescriptor(_AUTHFLOW_TYPE)


_WEBSOCKETCLIENTMESSAGE = _descriptor.Descriptor(
  name='WebSocketClientMessage',
  full_name='yamcs.protobuf.web.WebSocketClientMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='protocolVersion', full_name='yamcs.protobuf.web.WebSocketClientMessage.protocolVersion', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sequenceNumber', full_name='yamcs.protobuf.web.WebSocketClientMessage.sequenceNumber', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resource', full_name='yamcs.protobuf.web.WebSocketClientMessage.resource', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operation', full_name='yamcs.protobuf.web.WebSocketClientMessage.operation', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='yamcs.protobuf.web.WebSocketClientMessage.data', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=320,
  serialized_end=444,
)


_WEBSOCKETSERVERMESSAGE_WEBSOCKETREPLYDATA = _descriptor.Descriptor(
  name='WebSocketReplyData',
  full_name='yamcs.protobuf.web.WebSocketServerMessage.WebSocketReplyData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='protocolVersion', full_name='yamcs.protobuf.web.WebSocketServerMessage.WebSocketReplyData.protocolVersion', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sequenceNumber', full_name='yamcs.protobuf.web.WebSocketServerMessage.WebSocketReplyData.sequenceNumber', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.web.WebSocketServerMessage.WebSocketReplyData.type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='yamcs.protobuf.web.WebSocketServerMessage.WebSocketReplyData.message', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='yamcs.protobuf.web.WebSocketServerMessage.WebSocketReplyData.data', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=791,
  serialized_end=905,
)

_WEBSOCKETSERVERMESSAGE_WEBSOCKETEXCEPTIONDATA = _descriptor.Descriptor(
  name='WebSocketExceptionData',
  full_name='yamcs.protobuf.web.WebSocketServerMessage.WebSocketExceptionData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='protocolVersion', full_name='yamcs.protobuf.web.WebSocketServerMessage.WebSocketExceptionData.protocolVersion', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sequenceNumber', full_name='yamcs.protobuf.web.WebSocketServerMessage.WebSocketExceptionData.sequenceNumber', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.web.WebSocketServerMessage.WebSocketExceptionData.type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='yamcs.protobuf.web.WebSocketServerMessage.WebSocketExceptionData.message', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='yamcs.protobuf.web.WebSocketServerMessage.WebSocketExceptionData.data', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=907,
  serialized_end=1025,
)

_WEBSOCKETSERVERMESSAGE_WEBSOCKETSUBSCRIPTIONDATA = _descriptor.Descriptor(
  name='WebSocketSubscriptionData',
  full_name='yamcs.protobuf.web.WebSocketServerMessage.WebSocketSubscriptionData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sequenceNumber', full_name='yamcs.protobuf.web.WebSocketServerMessage.WebSocketSubscriptionData.sequenceNumber', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.web.WebSocketServerMessage.WebSocketSubscriptionData.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parameterData', full_name='yamcs.protobuf.web.WebSocketServerMessage.WebSocketSubscriptionData.parameterData', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='command', full_name='yamcs.protobuf.web.WebSocketServerMessage.WebSocketSubscriptionData.command', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processorInfo', full_name='yamcs.protobuf.web.WebSocketServerMessage.WebSocketSubscriptionData.processorInfo', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='clientInfo', full_name='yamcs.protobuf.web.WebSocketServerMessage.WebSocketSubscriptionData.clientInfo', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='statistics', full_name='yamcs.protobuf.web.WebSocketServerMessage.WebSocketSubscriptionData.statistics', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event', full_name='yamcs.protobuf.web.WebSocketServerMessage.WebSocketSubscriptionData.event', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='streamData', full_name='yamcs.protobuf.web.WebSocketServerMessage.WebSocketSubscriptionData.streamData', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='alarmData', full_name='yamcs.protobuf.web.WebSocketServerMessage.WebSocketSubscriptionData.alarmData', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeInfo', full_name='yamcs.protobuf.web.WebSocketServerMessage.WebSocketSubscriptionData.timeInfo', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='linkEvent', full_name='yamcs.protobuf.web.WebSocketServerMessage.WebSocketSubscriptionData.linkEvent', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commandQueueInfo', full_name='yamcs.protobuf.web.WebSocketServerMessage.WebSocketSubscriptionData.commandQueueInfo', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commandQueueEvent', full_name='yamcs.protobuf.web.WebSocketServerMessage.WebSocketSubscriptionData.commandQueueEvent', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tmPacket', full_name='yamcs.protobuf.web.WebSocketServerMessage.WebSocketSubscriptionData.tmPacket', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='connectionInfo', full_name='yamcs.protobuf.web.WebSocketServerMessage.WebSocketSubscriptionData.connectionInfo', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='streamEvent', full_name='yamcs.protobuf.web.WebSocketServerMessage.WebSocketSubscriptionData.streamEvent', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extensionData', full_name='yamcs.protobuf.web.WebSocketServerMessage.WebSocketSubscriptionData.extensionData', index=17,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1028,
  serialized_end=2084,
)

_WEBSOCKETSERVERMESSAGE = _descriptor.Descriptor(
  name='WebSocketServerMessage',
  full_name='yamcs.protobuf.web.WebSocketServerMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.web.WebSocketServerMessage.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reply', full_name='yamcs.protobuf.web.WebSocketServerMessage.reply', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exception', full_name='yamcs.protobuf.web.WebSocketServerMessage.exception', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='yamcs.protobuf.web.WebSocketServerMessage.data', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_WEBSOCKETSERVERMESSAGE_WEBSOCKETREPLYDATA, _WEBSOCKETSERVERMESSAGE_WEBSOCKETEXCEPTIONDATA, _WEBSOCKETSERVERMESSAGE_WEBSOCKETSUBSCRIPTIONDATA, ],
  enum_types=[
    _WEBSOCKETSERVERMESSAGE_MESSAGETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=447,
  serialized_end=2135,
)


_WEBSOCKETEXTENSIONDATA = _descriptor.Descriptor(
  name='WebSocketExtensionData',
  full_name='yamcs.protobuf.web.WebSocketExtensionData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.web.WebSocketExtensionData.type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='yamcs.protobuf.web.WebSocketExtensionData.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2137,
  serialized_end=2189,
)


_LINKSUBSCRIPTIONREQUEST = _descriptor.Descriptor(
  name='LinkSubscriptionRequest',
  full_name='yamcs.protobuf.web.LinkSubscriptionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.web.LinkSubscriptionRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2191,
  serialized_end=2234,
)


_STREAMSSUBSCRIPTIONREQUEST = _descriptor.Descriptor(
  name='StreamsSubscriptionRequest',
  full_name='yamcs.protobuf.web.StreamsSubscriptionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.web.StreamsSubscriptionRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2236,
  serialized_end=2282,
)


_CFDPSUBSCRIPTIONREQUEST = _descriptor.Descriptor(
  name='CfdpSubscriptionRequest',
  full_name='yamcs.protobuf.web.CfdpSubscriptionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.web.CfdpSubscriptionRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2284,
  serialized_end=2327,
)


_PROCESSORSUBSCRIPTIONREQUEST = _descriptor.Descriptor(
  name='ProcessorSubscriptionRequest',
  full_name='yamcs.protobuf.web.ProcessorSubscriptionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='allProcessors', full_name='yamcs.protobuf.web.ProcessorSubscriptionRequest.allProcessors', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='allInstances', full_name='yamcs.protobuf.web.ProcessorSubscriptionRequest.allInstances', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2329,
  serialized_end=2404,
)


_MANAGEMENTSUBSCRIPTIONREQUEST = _descriptor.Descriptor(
  name='ManagementSubscriptionRequest',
  full_name='yamcs.protobuf.web.ManagementSubscriptionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='clientInfo', full_name='yamcs.protobuf.web.ManagementSubscriptionRequest.clientInfo', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processorStatistics', full_name='yamcs.protobuf.web.ManagementSubscriptionRequest.processorStatistics', index=1,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2406,
  serialized_end=2486,
)


_ALARMSUBSCRIPTIONREQUEST = _descriptor.Descriptor(
  name='AlarmSubscriptionRequest',
  full_name='yamcs.protobuf.web.AlarmSubscriptionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='detail', full_name='yamcs.protobuf.web.AlarmSubscriptionRequest.detail', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2488,
  serialized_end=2530,
)


_COMMANDHISTORYSUBSCRIPTIONREQUEST = _descriptor.Descriptor(
  name='CommandHistorySubscriptionRequest',
  full_name='yamcs.protobuf.web.CommandHistorySubscriptionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='commandId', full_name='yamcs.protobuf.web.CommandHistorySubscriptionRequest.commandId', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ignorePastCommands', full_name='yamcs.protobuf.web.CommandHistorySubscriptionRequest.ignorePastCommands', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2532,
  serialized_end=2656,
)


_PARAMETERSUBSCRIPTIONREQUEST = _descriptor.Descriptor(
  name='ParameterSubscriptionRequest',
  full_name='yamcs.protobuf.web.ParameterSubscriptionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.web.ParameterSubscriptionRequest.id', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='abortOnInvalid', full_name='yamcs.protobuf.web.ParameterSubscriptionRequest.abortOnInvalid', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='updateOnExpiration', full_name='yamcs.protobuf.web.ParameterSubscriptionRequest.updateOnExpiration', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sendFromCache', full_name='yamcs.protobuf.web.ParameterSubscriptionRequest.sendFromCache', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subscriptionId', full_name='yamcs.protobuf.web.ParameterSubscriptionRequest.subscriptionId', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='useNumericIds', full_name='yamcs.protobuf.web.ParameterSubscriptionRequest.useNumericIds', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2659,
  serialized_end=2854,
)


_SUBSCRIBEDPARAMETER = _descriptor.Descriptor(
  name='SubscribedParameter',
  full_name='yamcs.protobuf.web.SubscribedParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.web.SubscribedParameter.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numericId', full_name='yamcs.protobuf.web.SubscribedParameter.numericId', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2856,
  serialized_end=2939,
)


_PARAMETERSUBSCRIPTIONRESPONSE = _descriptor.Descriptor(
  name='ParameterSubscriptionResponse',
  full_name='yamcs.protobuf.web.ParameterSubscriptionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='invalid', full_name='yamcs.protobuf.web.ParameterSubscriptionResponse.invalid', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subscriptionId', full_name='yamcs.protobuf.web.ParameterSubscriptionResponse.subscriptionId', index=1,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subscribed', full_name='yamcs.protobuf.web.ParameterSubscriptionResponse.subscribed', index=2,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2942,
  serialized_end=3106,
)


_TIMESUBSCRIPTIONRESPONSE = _descriptor.Descriptor(
  name='TimeSubscriptionResponse',
  full_name='yamcs.protobuf.web.TimeSubscriptionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timeInfo', full_name='yamcs.protobuf.web.TimeSubscriptionResponse.timeInfo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3108,
  serialized_end=3178,
)


_PROCESSORSUBSCRIPTIONRESPONSE = _descriptor.Descriptor(
  name='ProcessorSubscriptionResponse',
  full_name='yamcs.protobuf.web.ProcessorSubscriptionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.web.ProcessorSubscriptionResponse.processor', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3180,
  serialized_end=3277,
)


_CONNECTIONINFO = _descriptor.Descriptor(
  name='ConnectionInfo',
  full_name='yamcs.protobuf.web.ConnectionInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='clientId', full_name='yamcs.protobuf.web.ConnectionInfo.clientId', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.web.ConnectionInfo.instance', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.web.ConnectionInfo.processor', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3280,
  serialized_end=3445,
)


_AUTHFLOW = _descriptor.Descriptor(
  name='AuthFlow',
  full_name='yamcs.protobuf.web.AuthFlow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.web.AuthFlow.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _AUTHFLOW_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3447,
  serialized_end=3554,
)


_AUTHINFO = _descriptor.Descriptor(
  name='AuthInfo',
  full_name='yamcs.protobuf.web.AuthInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='requireAuthentication', full_name='yamcs.protobuf.web.AuthInfo.requireAuthentication', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flow', full_name='yamcs.protobuf.web.AuthInfo.flow', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3556,
  serialized_end=3641,
)


_TOKENRESPONSE = _descriptor.Descriptor(
  name='TokenResponse',
  full_name='yamcs.protobuf.web.TokenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='access_token', full_name='yamcs.protobuf.web.TokenResponse.access_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token_type', full_name='yamcs.protobuf.web.TokenResponse.token_type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expires_in', full_name='yamcs.protobuf.web.TokenResponse.expires_in', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='refresh_token', full_name='yamcs.protobuf.web.TokenResponse.refresh_token', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user', full_name='yamcs.protobuf.web.TokenResponse.user', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3644,
  serialized_end=3788,
)

_WEBSOCKETSERVERMESSAGE_WEBSOCKETREPLYDATA.containing_type = _WEBSOCKETSERVERMESSAGE
_WEBSOCKETSERVERMESSAGE_WEBSOCKETEXCEPTIONDATA.containing_type = _WEBSOCKETSERVERMESSAGE
_WEBSOCKETSERVERMESSAGE_WEBSOCKETSUBSCRIPTIONDATA.fields_by_name['type'].enum_type = yamcs_dot_protobuf_dot_yamcs__pb2._PROTODATATYPE
_WEBSOCKETSERVERMESSAGE_WEBSOCKETSUBSCRIPTIONDATA.fields_by_name['parameterData'].message_type = yamcs_dot_protobuf_dot_pvalue_dot_pvalue__pb2._PARAMETERDATA
_WEBSOCKETSERVERMESSAGE_WEBSOCKETSUBSCRIPTIONDATA.fields_by_name['command'].message_type = yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDHISTORYENTRY
_WEBSOCKETSERVERMESSAGE_WEBSOCKETSUBSCRIPTIONDATA.fields_by_name['processorInfo'].message_type = yamcs_dot_protobuf_dot_yamcsManagement_dot_yamcsManagement__pb2._PROCESSORINFO
_WEBSOCKETSERVERMESSAGE_WEBSOCKETSUBSCRIPTIONDATA.fields_by_name['clientInfo'].message_type = yamcs_dot_protobuf_dot_yamcsManagement_dot_yamcsManagement__pb2._CLIENTINFO
_WEBSOCKETSERVERMESSAGE_WEBSOCKETSUBSCRIPTIONDATA.fields_by_name['statistics'].message_type = yamcs_dot_protobuf_dot_yamcsManagement_dot_yamcsManagement__pb2._STATISTICS
_WEBSOCKETSERVERMESSAGE_WEBSOCKETSUBSCRIPTIONDATA.fields_by_name['event'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._EVENT
_WEBSOCKETSERVERMESSAGE_WEBSOCKETSUBSCRIPTIONDATA.fields_by_name['streamData'].message_type = yamcs_dot_protobuf_dot_table_dot_table__pb2._STREAMDATA
_WEBSOCKETSERVERMESSAGE_WEBSOCKETSUBSCRIPTIONDATA.fields_by_name['alarmData'].message_type = yamcs_dot_protobuf_dot_alarms_dot_alarms__pb2._ALARMDATA
_WEBSOCKETSERVERMESSAGE_WEBSOCKETSUBSCRIPTIONDATA.fields_by_name['timeInfo'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._TIMEINFO
_WEBSOCKETSERVERMESSAGE_WEBSOCKETSUBSCRIPTIONDATA.fields_by_name['linkEvent'].message_type = yamcs_dot_protobuf_dot_yamcsManagement_dot_yamcsManagement__pb2._LINKEVENT
_WEBSOCKETSERVERMESSAGE_WEBSOCKETSUBSCRIPTIONDATA.fields_by_name['commandQueueInfo'].message_type = yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDQUEUEINFO
_WEBSOCKETSERVERMESSAGE_WEBSOCKETSUBSCRIPTIONDATA.fields_by_name['commandQueueEvent'].message_type = yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDQUEUEEVENT
_WEBSOCKETSERVERMESSAGE_WEBSOCKETSUBSCRIPTIONDATA.fields_by_name['tmPacket'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._TMPACKETDATA
_WEBSOCKETSERVERMESSAGE_WEBSOCKETSUBSCRIPTIONDATA.fields_by_name['connectionInfo'].message_type = _CONNECTIONINFO
_WEBSOCKETSERVERMESSAGE_WEBSOCKETSUBSCRIPTIONDATA.fields_by_name['streamEvent'].message_type = yamcs_dot_protobuf_dot_yamcsManagement_dot_yamcsManagement__pb2._STREAMEVENT
_WEBSOCKETSERVERMESSAGE_WEBSOCKETSUBSCRIPTIONDATA.fields_by_name['extensionData'].message_type = _WEBSOCKETEXTENSIONDATA
_WEBSOCKETSERVERMESSAGE_WEBSOCKETSUBSCRIPTIONDATA.containing_type = _WEBSOCKETSERVERMESSAGE
_WEBSOCKETSERVERMESSAGE.fields_by_name['type'].enum_type = _WEBSOCKETSERVERMESSAGE_MESSAGETYPE
_WEBSOCKETSERVERMESSAGE.fields_by_name['reply'].message_type = _WEBSOCKETSERVERMESSAGE_WEBSOCKETREPLYDATA
_WEBSOCKETSERVERMESSAGE.fields_by_name['exception'].message_type = _WEBSOCKETSERVERMESSAGE_WEBSOCKETEXCEPTIONDATA
_WEBSOCKETSERVERMESSAGE.fields_by_name['data'].message_type = _WEBSOCKETSERVERMESSAGE_WEBSOCKETSUBSCRIPTIONDATA
_WEBSOCKETSERVERMESSAGE_MESSAGETYPE.containing_type = _WEBSOCKETSERVERMESSAGE
_COMMANDHISTORYSUBSCRIPTIONREQUEST.fields_by_name['commandId'].message_type = yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDID
_PARAMETERSUBSCRIPTIONREQUEST.fields_by_name['id'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._NAMEDOBJECTID
_SUBSCRIBEDPARAMETER.fields_by_name['id'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._NAMEDOBJECTID
_PARAMETERSUBSCRIPTIONRESPONSE.fields_by_name['invalid'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._NAMEDOBJECTID
_PARAMETERSUBSCRIPTIONRESPONSE.fields_by_name['subscribed'].message_type = _SUBSCRIBEDPARAMETER
_TIMESUBSCRIPTIONRESPONSE.fields_by_name['timeInfo'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._TIMEINFO
_PROCESSORSUBSCRIPTIONRESPONSE.fields_by_name['processor'].message_type = yamcs_dot_protobuf_dot_yamcsManagement_dot_yamcsManagement__pb2._PROCESSORINFO
_CONNECTIONINFO.fields_by_name['instance'].message_type = yamcs_dot_protobuf_dot_yamcsManagement_dot_yamcsManagement__pb2._YAMCSINSTANCE
_CONNECTIONINFO.fields_by_name['processor'].message_type = yamcs_dot_protobuf_dot_yamcsManagement_dot_yamcsManagement__pb2._PROCESSORINFO
_AUTHFLOW.fields_by_name['type'].enum_type = _AUTHFLOW_TYPE
_AUTHFLOW_TYPE.containing_type = _AUTHFLOW
_AUTHINFO.fields_by_name['flow'].message_type = _AUTHFLOW
_TOKENRESPONSE.fields_by_name['user'].message_type = yamcs_dot_protobuf_dot_iam_dot_iam__pb2._USERINFO
DESCRIPTOR.message_types_by_name['WebSocketClientMessage'] = _WEBSOCKETCLIENTMESSAGE
DESCRIPTOR.message_types_by_name['WebSocketServerMessage'] = _WEBSOCKETSERVERMESSAGE
DESCRIPTOR.message_types_by_name['WebSocketExtensionData'] = _WEBSOCKETEXTENSIONDATA
DESCRIPTOR.message_types_by_name['LinkSubscriptionRequest'] = _LINKSUBSCRIPTIONREQUEST
DESCRIPTOR.message_types_by_name['StreamsSubscriptionRequest'] = _STREAMSSUBSCRIPTIONREQUEST
DESCRIPTOR.message_types_by_name['CfdpSubscriptionRequest'] = _CFDPSUBSCRIPTIONREQUEST
DESCRIPTOR.message_types_by_name['ProcessorSubscriptionRequest'] = _PROCESSORSUBSCRIPTIONREQUEST
DESCRIPTOR.message_types_by_name['ManagementSubscriptionRequest'] = _MANAGEMENTSUBSCRIPTIONREQUEST
DESCRIPTOR.message_types_by_name['AlarmSubscriptionRequest'] = _ALARMSUBSCRIPTIONREQUEST
DESCRIPTOR.message_types_by_name['CommandHistorySubscriptionRequest'] = _COMMANDHISTORYSUBSCRIPTIONREQUEST
DESCRIPTOR.message_types_by_name['ParameterSubscriptionRequest'] = _PARAMETERSUBSCRIPTIONREQUEST
DESCRIPTOR.message_types_by_name['SubscribedParameter'] = _SUBSCRIBEDPARAMETER
DESCRIPTOR.message_types_by_name['ParameterSubscriptionResponse'] = _PARAMETERSUBSCRIPTIONRESPONSE
DESCRIPTOR.message_types_by_name['TimeSubscriptionResponse'] = _TIMESUBSCRIPTIONRESPONSE
DESCRIPTOR.message_types_by_name['ProcessorSubscriptionResponse'] = _PROCESSORSUBSCRIPTIONRESPONSE
DESCRIPTOR.message_types_by_name['ConnectionInfo'] = _CONNECTIONINFO
DESCRIPTOR.message_types_by_name['AuthFlow'] = _AUTHFLOW
DESCRIPTOR.message_types_by_name['AuthInfo'] = _AUTHINFO
DESCRIPTOR.message_types_by_name['TokenResponse'] = _TOKENRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

WebSocketClientMessage = _reflection.GeneratedProtocolMessageType('WebSocketClientMessage', (_message.Message,), {
  'DESCRIPTOR' : _WEBSOCKETCLIENTMESSAGE,
  '__module__' : 'yamcs.protobuf.web.websocket_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.WebSocketClientMessage)
  })
_sym_db.RegisterMessage(WebSocketClientMessage)

WebSocketServerMessage = _reflection.GeneratedProtocolMessageType('WebSocketServerMessage', (_message.Message,), {

  'WebSocketReplyData' : _reflection.GeneratedProtocolMessageType('WebSocketReplyData', (_message.Message,), {
    'DESCRIPTOR' : _WEBSOCKETSERVERMESSAGE_WEBSOCKETREPLYDATA,
    '__module__' : 'yamcs.protobuf.web.websocket_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.WebSocketServerMessage.WebSocketReplyData)
    })
  ,

  'WebSocketExceptionData' : _reflection.GeneratedProtocolMessageType('WebSocketExceptionData', (_message.Message,), {
    'DESCRIPTOR' : _WEBSOCKETSERVERMESSAGE_WEBSOCKETEXCEPTIONDATA,
    '__module__' : 'yamcs.protobuf.web.websocket_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.WebSocketServerMessage.WebSocketExceptionData)
    })
  ,

  'WebSocketSubscriptionData' : _reflection.GeneratedProtocolMessageType('WebSocketSubscriptionData', (_message.Message,), {
    'DESCRIPTOR' : _WEBSOCKETSERVERMESSAGE_WEBSOCKETSUBSCRIPTIONDATA,
    '__module__' : 'yamcs.protobuf.web.websocket_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.WebSocketServerMessage.WebSocketSubscriptionData)
    })
  ,
  'DESCRIPTOR' : _WEBSOCKETSERVERMESSAGE,
  '__module__' : 'yamcs.protobuf.web.websocket_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.WebSocketServerMessage)
  })
_sym_db.RegisterMessage(WebSocketServerMessage)
_sym_db.RegisterMessage(WebSocketServerMessage.WebSocketReplyData)
_sym_db.RegisterMessage(WebSocketServerMessage.WebSocketExceptionData)
_sym_db.RegisterMessage(WebSocketServerMessage.WebSocketSubscriptionData)

WebSocketExtensionData = _reflection.GeneratedProtocolMessageType('WebSocketExtensionData', (_message.Message,), {
  'DESCRIPTOR' : _WEBSOCKETEXTENSIONDATA,
  '__module__' : 'yamcs.protobuf.web.websocket_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.WebSocketExtensionData)
  })
_sym_db.RegisterMessage(WebSocketExtensionData)

LinkSubscriptionRequest = _reflection.GeneratedProtocolMessageType('LinkSubscriptionRequest', (_message.Message,), {
  'DESCRIPTOR' : _LINKSUBSCRIPTIONREQUEST,
  '__module__' : 'yamcs.protobuf.web.websocket_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.LinkSubscriptionRequest)
  })
_sym_db.RegisterMessage(LinkSubscriptionRequest)

StreamsSubscriptionRequest = _reflection.GeneratedProtocolMessageType('StreamsSubscriptionRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMSSUBSCRIPTIONREQUEST,
  '__module__' : 'yamcs.protobuf.web.websocket_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.StreamsSubscriptionRequest)
  })
_sym_db.RegisterMessage(StreamsSubscriptionRequest)

CfdpSubscriptionRequest = _reflection.GeneratedProtocolMessageType('CfdpSubscriptionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CFDPSUBSCRIPTIONREQUEST,
  '__module__' : 'yamcs.protobuf.web.websocket_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.CfdpSubscriptionRequest)
  })
_sym_db.RegisterMessage(CfdpSubscriptionRequest)

ProcessorSubscriptionRequest = _reflection.GeneratedProtocolMessageType('ProcessorSubscriptionRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROCESSORSUBSCRIPTIONREQUEST,
  '__module__' : 'yamcs.protobuf.web.websocket_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.ProcessorSubscriptionRequest)
  })
_sym_db.RegisterMessage(ProcessorSubscriptionRequest)

ManagementSubscriptionRequest = _reflection.GeneratedProtocolMessageType('ManagementSubscriptionRequest', (_message.Message,), {
  'DESCRIPTOR' : _MANAGEMENTSUBSCRIPTIONREQUEST,
  '__module__' : 'yamcs.protobuf.web.websocket_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.ManagementSubscriptionRequest)
  })
_sym_db.RegisterMessage(ManagementSubscriptionRequest)

AlarmSubscriptionRequest = _reflection.GeneratedProtocolMessageType('AlarmSubscriptionRequest', (_message.Message,), {
  'DESCRIPTOR' : _ALARMSUBSCRIPTIONREQUEST,
  '__module__' : 'yamcs.protobuf.web.websocket_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.AlarmSubscriptionRequest)
  })
_sym_db.RegisterMessage(AlarmSubscriptionRequest)

CommandHistorySubscriptionRequest = _reflection.GeneratedProtocolMessageType('CommandHistorySubscriptionRequest', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDHISTORYSUBSCRIPTIONREQUEST,
  '__module__' : 'yamcs.protobuf.web.websocket_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.CommandHistorySubscriptionRequest)
  })
_sym_db.RegisterMessage(CommandHistorySubscriptionRequest)

ParameterSubscriptionRequest = _reflection.GeneratedProtocolMessageType('ParameterSubscriptionRequest', (_message.Message,), {
  'DESCRIPTOR' : _PARAMETERSUBSCRIPTIONREQUEST,
  '__module__' : 'yamcs.protobuf.web.websocket_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.ParameterSubscriptionRequest)
  })
_sym_db.RegisterMessage(ParameterSubscriptionRequest)

SubscribedParameter = _reflection.GeneratedProtocolMessageType('SubscribedParameter', (_message.Message,), {
  'DESCRIPTOR' : _SUBSCRIBEDPARAMETER,
  '__module__' : 'yamcs.protobuf.web.websocket_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.SubscribedParameter)
  })
_sym_db.RegisterMessage(SubscribedParameter)

ParameterSubscriptionResponse = _reflection.GeneratedProtocolMessageType('ParameterSubscriptionResponse', (_message.Message,), {
  'DESCRIPTOR' : _PARAMETERSUBSCRIPTIONRESPONSE,
  '__module__' : 'yamcs.protobuf.web.websocket_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.ParameterSubscriptionResponse)
  })
_sym_db.RegisterMessage(ParameterSubscriptionResponse)

TimeSubscriptionResponse = _reflection.GeneratedProtocolMessageType('TimeSubscriptionResponse', (_message.Message,), {
  'DESCRIPTOR' : _TIMESUBSCRIPTIONRESPONSE,
  '__module__' : 'yamcs.protobuf.web.websocket_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.TimeSubscriptionResponse)
  })
_sym_db.RegisterMessage(TimeSubscriptionResponse)

ProcessorSubscriptionResponse = _reflection.GeneratedProtocolMessageType('ProcessorSubscriptionResponse', (_message.Message,), {
  'DESCRIPTOR' : _PROCESSORSUBSCRIPTIONRESPONSE,
  '__module__' : 'yamcs.protobuf.web.websocket_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.ProcessorSubscriptionResponse)
  })
_sym_db.RegisterMessage(ProcessorSubscriptionResponse)

ConnectionInfo = _reflection.GeneratedProtocolMessageType('ConnectionInfo', (_message.Message,), {
  'DESCRIPTOR' : _CONNECTIONINFO,
  '__module__' : 'yamcs.protobuf.web.websocket_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.ConnectionInfo)
  })
_sym_db.RegisterMessage(ConnectionInfo)

AuthFlow = _reflection.GeneratedProtocolMessageType('AuthFlow', (_message.Message,), {
  'DESCRIPTOR' : _AUTHFLOW,
  '__module__' : 'yamcs.protobuf.web.websocket_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.AuthFlow)
  })
_sym_db.RegisterMessage(AuthFlow)

AuthInfo = _reflection.GeneratedProtocolMessageType('AuthInfo', (_message.Message,), {
  'DESCRIPTOR' : _AUTHINFO,
  '__module__' : 'yamcs.protobuf.web.websocket_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.AuthInfo)
  })
_sym_db.RegisterMessage(AuthInfo)

TokenResponse = _reflection.GeneratedProtocolMessageType('TokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _TOKENRESPONSE,
  '__module__' : 'yamcs.protobuf.web.websocket_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.TokenResponse)
  })
_sym_db.RegisterMessage(TokenResponse)


DESCRIPTOR._options = None
_COMMANDHISTORYSUBSCRIPTIONREQUEST.fields_by_name['commandId']._options = None
# @@protoc_insertion_point(module_scope)



from yamcs.protobuf.mdb import mdb_pb2


class Algorithm(object):

    def __init__(self, proto):
        self._proto = proto

    @property
    def name(self):
        """Short name"""
        return self._proto.name

    @property
    def qualified_name(self):
        """Full name (incl. space system)"""
        return self._proto.qualifiedName

    @property
    def aliases(self):
        """List of (namespace, name) pairs, as 2-tuples"""
        return {alias.namespace: alias.name for alias in self._proto.alias}.items()

    @property
    def description(self):
        """Short description."""
        if self._proto.HasField('shortDescription'):
            return self._proto.shortDescription
        return None

    @property
    def long_description(self):
        """Long description."""
        if self._proto.HasField('longDescription'):
            return self._proto.longDescription
        return None

    def __str__(self):
        return self.qualified_name


class Command(object):

    def __init__(self, proto):
        self._proto = proto

    @property
    def name(self):
        """Short name"""
        return self._proto.name

    @property
    def qualified_name(self):
        """Full name (incl. space system)"""
        return self._proto.qualifiedName

    @property
    def aliases(self):
        """List of (namespace, name) pairs, as 2-tuples"""
        return {alias.namespace: alias.name for alias in self._proto.alias}.items()

    @property
    def description(self):
        """Short description."""
        if self._proto.HasField('shortDescription'):
            return self._proto.shortDescription
        return None

    @property
    def long_description(self):
        """Long description."""
        if self._proto.HasField('longDescription'):
            return self._proto.longDescription
        return None

    @property
    def base_command(self):
        if self._proto.HasField('baseCommand'):
            return Command(self._proto.baseCommand)
        return None

    @property
    def abstract(self):
        """
        Whether this is an abstract command. Abstract commands are
        intended for inheritance and cannot be issued directly.
        """
        return self._proto.abstract

    @property
    def significance(self):
        if self._proto.HasField('significance'):
            return Significance(self._proto.significance)
        return None

    def __str__(self):
        return self.qualified_name


class Significance(object):

    def __init__(self, proto):
        self._proto = proto

    @property
    def consequence_level(self):
        """
        One of ``NONE``, ``WATCH``, ``WARNING``, ``DISTRESS``, ``CRITICAL``
        or ``SEVERE``.
        """
        if self._proto.HasField('consequenceLevel'):
            return mdb_pb2.SignificanceInfo.SignificanceLevelType.Name(self._proto.consequenceLevel)
        return None

    @property
    def reason(self):
        """Message attached to this significance."""
        if self._proto.HasField('reasonForWarning'):
            return self._proto.reasonForWarning
        return None

    def __str__(self):
        return '[{}] {}'.format(self.consequence_level, self.reason)


class Container(object):

    def __init__(self, proto):
        self._proto = proto

    @property
    def name(self):
        """Short name"""
        return self._proto.name

    @property
    def qualified_name(self):
        """Full name (incl. space system)"""
        return self._proto.qualifiedName

    @property
    def aliases(self):
        """List of (namespace, name) pairs, as 2-tuples"""
        return {alias.namespace: alias.name for alias in self._proto.alias}.items()

    @property
    def description(self):
        """Short description."""
        if self._proto.HasField('shortDescription'):
            return self._proto.shortDescription
        return None

    @property
    def long_description(self):
        """Long description."""
        if self._proto.HasField('longDescription'):
            return self._proto.longDescription
        return None

    def __str__(self):
        return self.qualified_name


class Parameter(object):
    """
    From XTCE:

        A Parameter is a description of something that can have
        a value. It is not the value itself.
    """

    def __init__(self, proto):
        self._proto = proto

    @property
    def name(self):
        """Short name"""
        return self._proto.name

    @property
    def qualified_name(self):
        """Full name (incl. space system)"""
        return self._proto.qualifiedName

    @property
    def aliases(self):
        """List of (namespace, name) pairs, as 2-tuples"""
        return {alias.namespace: alias.name for alias in self._proto.alias}.items()

    @property
    def description(self):
        """Short description."""
        if self._proto.HasField('shortDescription'):
            return self._proto.shortDescription
        return None

    @property
    def long_description(self):
        """Long description."""
        if self._proto.HasField('longDescription'):
            return self._proto.longDescription
        return None

    @property
    def data_source(self):
        """Specifies how this parameter originated (example: ``TELEMETERED``)"""
        if self._proto.HasField('dataSource'):
            return mdb_pb2.DataSourceType.Name(self._proto.dataSource)
        return None

    def __str__(self):
        return self.qualified_name


class SpaceSystem(object):
    """
    From XTCE:

        A SpaceSystem is a collection of SpaceSystem(s) including space assets,
        ground assets, multi-satellite systems and sub-systems.  A SpaceSystem
        is the root element for the set of data necessary to monitor and command
        an arbitrary space device - this includes the binary decomposition of
        the data streams going into and out of a device.
    """

    def __init__(self, proto):
        self._proto = proto

    @property
    def name(self):
        """Short name"""
        return self._proto.name

    @property
    def qualified_name(self):
        """Full name (incl. space system)"""
        return self._proto.qualifiedName

    @property
    def aliases(self):
        """List of (namespace, name) pairs, as 2-tuples"""
        return {alias.namespace: alias.name for alias in self._proto.alias}.items()

    @property
    def description(self):
        """Short description."""
        if self._proto.HasField('shortDescription'):
            return self._proto.shortDescription
        return None

    @property
    def long_description(self):
        """Long description."""
        if self._proto.HasField('longDescription'):
            return self._proto.longDescription
        return None

    def __str__(self):
        return self.qualified_name
